==> kconfig-5.70.0-1-aarch64.pkg.tar.xz: usr/include/KF5/KConfigGui/kconfiggui_export.h <==

#ifndef KCONFIGGUI_EXPORT_H
#define KCONFIGGUI_EXPORT_H

#ifdef KCONFIGGUI_STATIC_DEFINE
#  define KCONFIGGUI_EXPORT
#  define KCONFIGGUI_NO_EXPORT
#else
#  ifndef KCONFIGGUI_EXPORT
#    ifdef KF5ConfigGui_EXPORTS
        /* We are building this library */
#      define KCONFIGGUI_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KCONFIGGUI_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KCONFIGGUI_NO_EXPORT
#    define KCONFIGGUI_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KCONFIGGUI_DECL_DEPRECATED
#  define KCONFIGGUI_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCONFIGGUI_DECL_DEPRECATED_EXPORT
#  define KCONFIGGUI_DECL_DEPRECATED_EXPORT KCONFIGGUI_EXPORT KCONFIGGUI_DECL_DEPRECATED
#endif

#ifndef KCONFIGGUI_DECL_DEPRECATED_NO_EXPORT
#  define KCONFIGGUI_DECL_DEPRECATED_NO_EXPORT KCONFIGGUI_NO_EXPORT KCONFIGGUI_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCONFIGGUI_NO_DEPRECATED
#    define KCONFIGGUI_NO_DEPRECATED
#  endif
#endif

#define KCONFIGGUI_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KCONFIGGUI_NO_DEPRECATED) && !defined(KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCONFIGGUI_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCONFIGGUI_NO_DEPRECATED_WARNINGS) && !defined(KCONFIGGUI_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCONFIGGUI_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCONFIGGUI_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCONFIGGUI_NO_DEPRECATED)
#  undef KCONFIGGUI_DEPRECATED
#  define KCONFIGGUI_DEPRECATED_EXPORT KCONFIGGUI_EXPORT
#  define KCONFIGGUI_DEPRECATED_NO_EXPORT KCONFIGGUI_NO_EXPORT
#elif defined(KCONFIGGUI_NO_DEPRECATED_WARNINGS)
#  define KCONFIGGUI_DEPRECATED
#  define KCONFIGGUI_DEPRECATED_EXPORT KCONFIGGUI_EXPORT
#  define KCONFIGGUI_DEPRECATED_NO_EXPORT KCONFIGGUI_NO_EXPORT
#else
#  define KCONFIGGUI_DEPRECATED KCONFIGGUI_DECL_DEPRECATED
#  define KCONFIGGUI_DEPRECATED_EXPORT KCONFIGGUI_DECL_DEPRECATED_EXPORT
#  define KCONFIGGUI_DEPRECATED_NO_EXPORT KCONFIGGUI_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCONFIGGUI_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCONFIGGUI_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCONFIGGUI_NO_DEPRECATED
#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54600
#endif
#ifdef KCONFIGGUI_NO_DEPRECATED_WARNINGS
#  define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCONFIGGUI_DEPRECATED_WARNINGS_SINCE
#  ifdef KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x54600
#  endif
#endif

#ifndef KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCONFIGGUI_DEPRECATED
#  define KCONFIGGUI_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCONFIGGUI_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KCONFIGGUI_DEPRECATED_WARNINGS_SINCE >= 0x50b00
#  define KCONFIGGUI_DEPRECATED_VERSION_5_11(text) KCONFIGGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGGUI_DEPRECATED_VERSION_5_11(text)
#endif

#if KCONFIGGUI_DEPRECATED_WARNINGS_SINCE >= 0x52700
#  define KCONFIGGUI_DEPRECATED_VERSION_5_39(text) KCONFIGGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGGUI_DEPRECATED_VERSION_5_39(text)
#endif
#define KCONFIGGUI_DEPRECATED_VERSION_5(minor, text)      KCONFIGGUI_DEPRECATED_VERSION_5_##minor(text)
#define KCONFIGGUI_DEPRECATED_VERSION(major, minor, text) KCONFIGGUI_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)

#endif /* KCONFIGGUI_EXPORT_H */

==> kconfig-5.71.0-1-aarch64.pkg.tar.xz: usr/include/KF5/KConfigGui/kconfiggui_export.h <==

#ifndef KCONFIGGUI_EXPORT_H
#define KCONFIGGUI_EXPORT_H

#ifdef KCONFIGGUI_STATIC_DEFINE
#  define KCONFIGGUI_EXPORT
#  define KCONFIGGUI_NO_EXPORT
#else
#  ifndef KCONFIGGUI_EXPORT
#    ifdef KF5ConfigGui_EXPORTS
        /* We are building this library */
#      define KCONFIGGUI_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KCONFIGGUI_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KCONFIGGUI_NO_EXPORT
#    define KCONFIGGUI_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KCONFIGGUI_DECL_DEPRECATED
#  define KCONFIGGUI_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCONFIGGUI_DECL_DEPRECATED_EXPORT
#  define KCONFIGGUI_DECL_DEPRECATED_EXPORT KCONFIGGUI_EXPORT KCONFIGGUI_DECL_DEPRECATED
#endif

#ifndef KCONFIGGUI_DECL_DEPRECATED_NO_EXPORT
#  define KCONFIGGUI_DECL_DEPRECATED_NO_EXPORT KCONFIGGUI_NO_EXPORT KCONFIGGUI_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCONFIGGUI_NO_DEPRECATED
#    define KCONFIGGUI_NO_DEPRECATED
#  endif
#endif

#define KCONFIGGUI_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KCONFIGGUI_NO_DEPRECATED) && !defined(KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCONFIGGUI_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCONFIGGUI_NO_DEPRECATED_WARNINGS) && !defined(KCONFIGGUI_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCONFIGGUI_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCONFIGGUI_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCONFIGGUI_NO_DEPRECATED)
#  undef KCONFIGGUI_DEPRECATED
#  define KCONFIGGUI_DEPRECATED_EXPORT KCONFIGGUI_EXPORT
#  define KCONFIGGUI_DEPRECATED_NO_EXPORT KCONFIGGUI_NO_EXPORT
#elif defined(KCONFIGGUI_NO_DEPRECATED_WARNINGS)
#  define KCONFIGGUI_DEPRECATED
#  define KCONFIGGUI_DEPRECATED_EXPORT KCONFIGGUI_EXPORT
#  define KCONFIGGUI_DEPRECATED_NO_EXPORT KCONFIGGUI_NO_EXPORT
#else
#  define KCONFIGGUI_DEPRECATED KCONFIGGUI_DECL_DEPRECATED
#  define KCONFIGGUI_DEPRECATED_EXPORT KCONFIGGUI_DECL_DEPRECATED_EXPORT
#  define KCONFIGGUI_DEPRECATED_NO_EXPORT KCONFIGGUI_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCONFIGGUI_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCONFIGGUI_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCONFIGGUI_NO_DEPRECATED
#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54700
#endif
#ifdef KCONFIGGUI_NO_DEPRECATED_WARNINGS
#  define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCONFIGGUI_DEPRECATED_WARNINGS_SINCE
#  ifdef KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x54700
#  endif
#endif

#ifndef KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCONFIGGUI_DEPRECATED
#  define KCONFIGGUI_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCONFIGGUI_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KCONFIGGUI_DEPRECATED_WARNINGS_SINCE >= 0x50b00
#  define KCONFIGGUI_DEPRECATED_VERSION_5_11(text) KCONFIGGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGGUI_DEPRECATED_VERSION_5_11(text)
#endif

#if KCONFIGGUI_DEPRECATED_WARNINGS_SINCE >= 0x52700
#  define KCONFIGGUI_DEPRECATED_VERSION_5_39(text) KCONFIGGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGGUI_DEPRECATED_VERSION_5_39(text)
#endif

#if KCONFIGGUI_DEPRECATED_WARNINGS_SINCE >= 0x54700
#  define KCONFIGGUI_DEPRECATED_VERSION_5_71(text) KCONFIGGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KCONFIGGUI_DEPRECATED_VERSION_5_71(text)
#endif
#define KCONFIGGUI_DEPRECATED_VERSION_5(minor, text)      KCONFIGGUI_DEPRECATED_VERSION_5_##minor(text)
#define KCONFIGGUI_DEPRECATED_VERSION(major, minor, text) KCONFIGGUI_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KCONFIGGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGGUI_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)

#endif /* KCONFIGGUI_EXPORT_H */
